==> haskell-paramtree-0.1.2-69.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-paramtree.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 paramtree
version:              0.1.2
visibility:           public
id:                   paramtree-0.1.2-kjS927qxt02iQAiUkyBNU
key:                  paramtree-0.1.2-kjS927qxt02iQAiUkyBNU
license:              BSD-3-Clause
copyright:            Copyright © 2017-2023 Merijn Verstraaten
maintainer:           Merijn Verstraaten <merijn@inconsistent.nl>
author:               Merijn Verstraaten
homepage:             https://github.com/merijn/paramtree
synopsis:
    Generate labelled test/benchmark trees from sets of parameters

description:
    Easily generate a labelled tree of tests/benchmarks from a generation
    function and sets of parameters to use for each of that functions
    arguments. Example usecases include criterion benchmark trees or tasty test
    trees.

category:             Development, Benchmarking, Testing
abi:                  e8b909ac75f99b2438d6790e6dbb8b36
exposed:              True
exposed-modules:      ParamTree
import-dirs:          /usr/lib/ghc-9.6.6/site-local/paramtree-0.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/paramtree-0.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/paramtree-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-paramtree
hs-libraries:         HSparamtree-0.1.2-kjS927qxt02iQAiUkyBNU
depends:              base-4.18.2.1 containers-0.6.7
haddock-interfaces:   /usr/share/doc/haskell-paramtree/html/paramtree.haddock
haddock-html:         /usr/share/doc/haskell-paramtree/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-paramtree-0.1.2-70-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-paramtree.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 paramtree
version:              0.1.2
visibility:           public
id:                   paramtree-0.1.2-IDKHXktkhFtI5mPsm3anrp
key:                  paramtree-0.1.2-IDKHXktkhFtI5mPsm3anrp
license:              BSD-3-Clause
copyright:            Copyright © 2017-2023 Merijn Verstraaten
maintainer:           Merijn Verstraaten <merijn@inconsistent.nl>
author:               Merijn Verstraaten
homepage:             https://github.com/merijn/paramtree
synopsis:
    Generate labelled test/benchmark trees from sets of parameters

description:
    Easily generate a labelled tree of tests/benchmarks from a generation
    function and sets of parameters to use for each of that functions
    arguments. Example usecases include criterion benchmark trees or tasty test
    trees.

category:             Development, Benchmarking, Testing
abi:                  4e0655601f74056df74286dcc98c44cc
exposed:              True
exposed-modules:      ParamTree
import-dirs:          /usr/lib/ghc-9.6.6/site-local/paramtree-0.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/paramtree-0.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/paramtree-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-paramtree
hs-libraries:         HSparamtree-0.1.2-IDKHXktkhFtI5mPsm3anrp
depends:              base-4.18.2.1 containers-0.6.7
haddock-interfaces:   /usr/share/doc/haskell-paramtree/html/paramtree.haddock
haddock-html:         /usr/share/doc/haskell-paramtree/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
